@@ -27,6 +27,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <sys/syslog.h>
 #include <pwd.h>
 #include <krb5.h>
 #include <kadm5/admin.h>
@@ -41,13 +42,4 @@
 
 #include <security/pam_modules.h>
 
-#ifndef False
-#define False (0)
-#endif
-
-#ifndef True
-#define True (1)
-#endif
-
-
 #endif /* _PAM_KRB5_MIGRATE_H */
